import { addSchema } from "@kubernetes-models/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@kubernetes-models/base";
import { register } from "@kubernetes-models/validate";
const schemaId = "policy.linkerd.io.v1alpha1.Server";
const schema = {
    "type": "object",
    "properties": {
        "spec": {
            "type": "object",
            "required": [
                "podSelector",
                "port"
            ],
            "properties": {
                "podSelector": {
                    "type": "object",
                    "oneOf": [
                        {
                            "required": [
                                "matchExpressions"
                            ]
                        },
                        {
                            "required": [
                                "matchLabels"
                            ]
                        }
                    ],
                    "properties": {
                        "matchLabels": {
                            "type": "object",
                            "properties": {},
                            "nullable": true
                        },
                        "matchExpressions": {
                            "type": "array",
                            "items": {
                                "type": "object",
                                "required": [
                                    "key",
                                    "operator"
                                ],
                                "properties": {
                                    "key": {
                                        "type": "string"
                                    },
                                    "operator": {
                                        "type": "string",
                                        "enum": [
                                            "In",
                                            "NotIn",
                                            "Exists",
                                            "DoesNotExist"
                                        ]
                                    },
                                    "values": {
                                        "type": "array",
                                        "items": {
                                            "type": "string"
                                        },
                                        "nullable": true
                                    }
                                }
                            },
                            "nullable": true
                        }
                    }
                },
                "port": {},
                "proxyProtocol": {
                    "type": "string",
                    "default": "unknown",
                    "nullable": true
                }
            }
        },
        "apiVersion": {
            "type": "string",
            "enum": [
                "policy.linkerd.io/v1alpha1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "Server"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        }
    },
    "required": [
        "spec",
        "apiVersion",
        "kind"
    ]
};
export class Server extends Model {
    constructor(data) {
        super({
            apiVersion: Server.apiVersion,
            kind: Server.kind,
            ...data
        });
    }
}
Server.apiVersion = "policy.linkerd.io/v1alpha1";
Server.kind = "Server";
Server.is = createTypeMetaGuard(Server);
setSchema(Server, schemaId, () => {
    addSchema();
    register(schemaId, schema);
});
