"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServerAuthorization = void 0;
const IoK8sApimachineryPkgApisMetaV1ObjectMeta_1 = require("@kubernetes-models/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta");
const base_1 = require("@kubernetes-models/base");
const validate_1 = require("@kubernetes-models/validate");
const schemaId = "policy.linkerd.io.v1beta1.ServerAuthorization";
const schema = {
    "type": "object",
    "properties": {
        "spec": {
            "type": "object",
            "required": [
                "server",
                "client"
            ],
            "properties": {
                "server": {
                    "type": "object",
                    "oneOf": [
                        {
                            "required": [
                                "name"
                            ]
                        },
                        {
                            "required": [
                                "selector"
                            ]
                        }
                    ],
                    "properties": {
                        "name": {
                            "type": "string",
                            "pattern": "^[a-z0-9]([-a-z0-9]*[a-z0-9])?$",
                            "nullable": true
                        },
                        "selector": {
                            "type": "object",
                            "properties": {
                                "matchLabels": {
                                    "type": "object",
                                    "properties": {},
                                    "nullable": true
                                },
                                "matchExpressions": {
                                    "type": "array",
                                    "items": {
                                        "type": "object",
                                        "required": [
                                            "key",
                                            "operator"
                                        ],
                                        "properties": {
                                            "key": {
                                                "type": "string"
                                            },
                                            "operator": {
                                                "type": "string",
                                                "enum": [
                                                    "In",
                                                    "NotIn",
                                                    "Exists",
                                                    "DoesNotExist"
                                                ]
                                            },
                                            "values": {
                                                "type": "array",
                                                "items": {
                                                    "type": "string"
                                                },
                                                "nullable": true
                                            }
                                        }
                                    },
                                    "nullable": true
                                }
                            },
                            "nullable": true
                        }
                    }
                },
                "client": {
                    "type": "object",
                    "properties": {
                        "networks": {
                            "type": "array",
                            "items": {
                                "type": "object",
                                "required": [
                                    "cidr"
                                ],
                                "properties": {
                                    "cidr": {
                                        "type": "string"
                                    },
                                    "except": {
                                        "type": "array",
                                        "items": {
                                            "type": "string"
                                        },
                                        "nullable": true
                                    }
                                }
                            },
                            "nullable": true
                        },
                        "unauthenticated": {
                            "type": "boolean",
                            "nullable": true
                        },
                        "meshTLS": {
                            "type": "object",
                            "properties": {
                                "unauthenticatedTLS": {
                                    "type": "boolean",
                                    "nullable": true
                                },
                                "identities": {
                                    "type": "array",
                                    "items": {
                                        "type": "string",
                                        "pattern": "^(\\*|[a-z0-9]([-a-z0-9]*[a-z0-9])?)(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$"
                                    },
                                    "nullable": true
                                },
                                "serviceAccounts": {
                                    "type": "array",
                                    "items": {
                                        "type": "object",
                                        "required": [
                                            "name"
                                        ],
                                        "properties": {
                                            "name": {
                                                "type": "string",
                                                "pattern": "^[a-z0-9]([-a-z0-9]*[a-z0-9])?$"
                                            },
                                            "namespace": {
                                                "type": "string",
                                                "pattern": "^[a-z0-9]([-a-z0-9]*[a-z0-9])?$",
                                                "nullable": true
                                            }
                                        }
                                    },
                                    "nullable": true
                                }
                            },
                            "nullable": true
                        }
                    }
                }
            }
        },
        "apiVersion": {
            "type": "string",
            "enum": [
                "policy.linkerd.io/v1beta1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "ServerAuthorization"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        }
    },
    "required": [
        "spec",
        "apiVersion",
        "kind"
    ]
};
class ServerAuthorization extends base_1.Model {
    constructor(data) {
        super({
            apiVersion: ServerAuthorization.apiVersion,
            kind: ServerAuthorization.kind,
            ...data
        });
    }
}
exports.ServerAuthorization = ServerAuthorization;
ServerAuthorization.apiVersion = "policy.linkerd.io/v1beta1";
ServerAuthorization.kind = "ServerAuthorization";
ServerAuthorization.is = (0, base_1.createTypeMetaGuard)(ServerAuthorization);
(0, base_1.setSchema)(ServerAuthorization, schemaId, () => {
    (0, IoK8sApimachineryPkgApisMetaV1ObjectMeta_1.addSchema)();
    (0, validate_1.register)(schemaId, schema);
});
